@@ -29,7 +29,9 @@
     if (Configuration::instance().at("print_config_only").value<bool>())                           \
     {                                                                                              \
         Configuration::instance().at("quiet").set_value(true);                                     \
-        std::cout << Configuration::instance().dump(true, true, true) << std::endl;                \
+        int dump_opts                                                                              \
+            = MAMBA_SHOW_CONFIG_VALUES | MAMBA_SHOW_CONFIG_SRCS | MAMBA_SHOW_ALL_CONFIGS;          \
+        std::cout << Configuration::instance().dump(dump_opts) << std::endl;                       \
         exit(0);                                                                                   \
     }
 #define DEBUG_QUIET                                                                                \
@@ -491,13 +493,11 @@ namespace mamba
     };
 
     int const MAMBA_NO_PREFIX_CHECK = 1 << 0;
-    int const MAMBA_ALLOW_ROOT_PREFIX = 1 << 1;
-    int const MAMBA_ALLOW_EXISTING_PREFIX = 1 << 2;
-    int const MAMBA_ALLOW_MISSING_PREFIX = 1 << 3;
-    int const MAMBA_ALLOW_NOT_ENV_PREFIX = 1 << 4;
-    int const MAMBA_EXPECT_EXISTING_PREFIX = 1 << 5;
+    int const MAMBA_ALLOW_EXISTING_PREFIX = 1 << 1;
+    int const MAMBA_ALLOW_MISSING_PREFIX = 1 << 2;
+    int const MAMBA_ALLOW_NOT_ENV_PREFIX = 1 << 3;
+    int const MAMBA_EXPECT_EXISTING_PREFIX = 1 << 4;
 
-    int const MAMBA_NOT_ALLOW_ROOT_PREFIX = 0;
     int const MAMBA_NOT_ALLOW_EXISTING_PREFIX = 0;
     int const MAMBA_NOT_ALLOW_MISSING_PREFIX = 0;
     int const MAMBA_NOT_ALLOW_NOT_ENV_PREFIX = 0;
@@ -559,6 +559,8 @@ namespace mamba
 
         bool configured() const;
 
+        bool has_single_op_lifetime() const;
+
         self_type& set_rc_value(const T& value, const std::string& source);
 
         self_type& set_rc_values(const std::map<std::string, T>& mapped_values,
@@ -576,6 +578,8 @@ namespace mamba
 
         self_type& clear_values();
 
+        self_type& set_single_op_lifetime();
+
         self_type& set_env_var_name(const std::string& name = "");
 
         self_type& group(const std::string& group);
@@ -623,12 +627,14 @@ namespace mamba
         bool m_lock = false;
         int m_compute_counter = 0;
 
+        bool m_single_op_lifetime = false;
+
         std::set<std::string> m_needed_configs, m_implied_configs;
 
         std::map<std::string, T> m_rc_values, m_values;
         std::vector<std::string> m_rc_sources, m_sources;
 
-        T m_value;
+        T m_value, m_default_value;
         std::vector<std::string> m_source;
 
         std::shared_ptr<cli_config_type> p_cli_config = 0;
@@ -644,6 +650,7 @@ namespace mamba
     Configurable<T>::Configurable(const std::string& name, T* context)
         : m_name(name)
         , m_value(*context)
+        , m_default_value(*context)
         , m_source(detail::Source<T>::default_value(*context))
         , p_context(context){};
 
@@ -651,6 +658,7 @@ namespace mamba
     Configurable<T>::Configurable(const std::string& name, const T& init)
         : m_name(name)
         , m_value(init)
+        , m_default_value(init)
         , m_source(detail::Source<T>::default_value(init)){};
 
     template <class T>
@@ -746,6 +754,12 @@ namespace mamba
         return rc_configured() || env_var_configured() || cli_configured() || api_configured();
     };
 
+    template <class T>
+    bool Configurable<T>::has_single_op_lifetime() const
+    {
+        return m_single_op_lifetime;
+    };
+
     template <class T>
     auto Configurable<T>::set_context() -> self_type&
     {
@@ -781,9 +795,12 @@ namespace mamba
     {
         if (p_cli_config == NULL)
         {
-            throw std::runtime_error("Configurable '" + m_name + "' does not have CLI set.");
+            p_cli_config = std::make_shared<cli_config_type>(value);
+        }
+        else
+        {
+            p_cli_config->m_value = value;
         }
-        p_cli_config->m_value = value;
 
         return *this;
     };
@@ -802,6 +819,13 @@ namespace mamba
         m_compute_counter = 0;
     }
 
+    template <class T>
+    auto Configurable<T>::set_single_op_lifetime() -> self_type&
+    {
+        m_single_op_lifetime = true;
+        return *this;
+    }
+
     template <class T>
     void Configurable<T>::lock()
     {
@@ -874,6 +898,8 @@ namespace mamba
         clear_env_value();
         clear_cli_value();
         clear_api_value();
+        m_value = m_default_value;
+
         return *this;
     };
 
@@ -993,6 +1019,8 @@ namespace mamba
 
             virtual const std::set<std::string>& implied() const = 0;
 
+            virtual bool has_single_op_lifetime() const = 0;
+
             virtual bool locked() = 0;
 
             virtual void reset_compute_counter() = 0;
@@ -1127,6 +1155,11 @@ namespace mamba
                 return p_wrapped->implied();
             }
 
+            bool has_single_op_lifetime() const
+            {
+                return p_wrapped->has_single_op_lifetime();
+            }
+
             bool locked()
             {
                 return p_wrapped->locked();
@@ -1189,7 +1222,15 @@ namespace mamba
 
             void set_yaml_value(const std::string& value)
             {
-                p_wrapped->set_value(detail::Source<T>::deserialize(value));
+                try
+                {
+                    p_wrapped->set_value(detail::Source<T>::deserialize(value));
+                }
+                catch (const YAML::Exception& e)
+                {
+                    LOG_ERROR << "Bad conversion of configurable '" << name() << "'";
+                    throw e;
+                }
             };
 
             void clear_rc_values()
@@ -1393,6 +1434,11 @@ namespace mamba
             p_impl->free();
         }
 
+        bool has_single_op_lifetime() const
+        {
+            return p_impl->has_single_op_lifetime();
+        }
+
         bool locked()
         {
             return p_impl->locked();
@@ -1522,6 +1568,15 @@ namespace mamba
         void check_target_prefix(int options);
     }
 
+
+    int const MAMBA_SHOW_CONFIG_VALUES = 1 << 0;
+    int const MAMBA_SHOW_CONFIG_SRCS = 1 << 1;
+    int const MAMBA_SHOW_CONFIG_DESCS = 1 << 2;
+    int const MAMBA_SHOW_CONFIG_LONG_DESCS = 1 << 3;
+    int const MAMBA_SHOW_CONFIG_GROUPS = 1 << 4;
+    int const MAMBA_SHOW_ALL_CONFIGS = 1 << 5;
+
+
     /*****************
      * Configuration *
      * ***************/
@@ -1550,13 +1605,19 @@ namespace mamba
 
         void clear_rc_values();
 
-        std::string dump(bool show_values = true,
-                         bool show_sources = false,
-                         bool show_defaults = false,
-                         bool show_sections = false,
-                         bool show_desc = false,
-                         bool long_desc = false,
-                         std::vector<std::string> names = {});
+        void clear_cli_values();
+
+        /**
+         * Pop values that should have a single operation lifetime to avoid memroy effect
+         * between multiple operations.
+         * It corresponds to CLI values in most of the cases, but may also include API
+         * values if the `Configurable::has_single_op_lifetime` method returns true.
+         * RC files and environment variables are always overriden when loading the
+         * configuration.
+         */
+        void operation_teardown();
+
+        std::string dump(int opts = MAMBA_SHOW_CONFIG_VALUES, std::vector<std::string> names = {});
 
         template <class T>
         typename detail::cli_config<T>::storage_type& link_cli_option(
@@ -1651,6 +1712,8 @@ namespace mamba
             m_values.insert(m_rc_values.begin(), m_rc_values.end());
         }
 
+        m_value = m_default_value;
+
         if (!m_sources.empty())
             detail::Source<T>::merge(m_values, m_sources, m_value, m_source);
 
